@@ -17,7 +17,6 @@ class Mkref_fusion(Mkref):
     --genome_name {genome_name} \\
     --fasta fusion.fasta \\
     --fusion_pos fusion_pos.txt \\
-    --genomeSAindexNbases 4
     ```
     """
 
@@ -33,7 +32,7 @@ class Mkref_fusion(Mkref):
 
 def mkref(args):
     genome_type = 'fusion'
-    with Mkref_fusion(genome_type, args, files=('fusion_pos',), non_files=('genomeSAindexNbases',)) as runner:
+    with Mkref_fusion(genome_type, args, files=('fusion_pos',), ) as runner:
         runner.run()
 
 
@@ -53,4 +52,4 @@ PML_5\t326
 PML_6\t204   
 """,
             required=True,)
-        parser.add_argument("--genomeSAindexNbases", help="STAR genomeSAindexNbases", default=14)
+
