@@ -16,8 +16,6 @@ class Mapping_vdj(Step):
     - Align R2 reads to IGMT(http://www.imgt.org/) database sequences with mixcr.
 
     ## Output
-    - `{sample}_consensus.fasta` Fasta file after UMI consensus.
-
     - `{sample}_UMI_count_unfiltered.tsv` UMI reading for each (barcode, chain, VJ_pair) combination.
 
     - `{sample}_UMI_count_filtered.tsv` For each (barcode, chain) combination, only the record with the 
@@ -57,11 +55,13 @@ class Mapping_vdj(Step):
             '-OallowPartialAlignments=true '
             '-OvParameters.geneFeatureToAlign=VTranscriptWithP '
             f'{self.args.fq} {self.read2_vdjca} '
+            f'-Xmx{self.args.mixcr_mem}g '
             '\n'
             'mixcr exportAlignments '
             f'{self.read2_vdjca} {self.alignments} '
             '-readIds --force-overwrite -vGene -dGene -jGene -cGene '
             '-nFeature CDR3 -aaFeature CDR3 '
+            f'-Xmx{self.args.mixcr_mem}g '
         )
 
         self.debug_subprocess_call(cmd)
@@ -219,6 +219,11 @@ def get_opts_mapping_vdj(parser, sub_program):
         help='Default `hs`. `hs`(human) or `mmu`(mouse). ',
         default='hs'
     )
+    parser.add_argument(
+        '--mixcr_mem',
+        help='Memory(in Gb) used by Java vitual machine.',
+        default=8,
+    )
     parser.add_argument("--not_consensus", action='store_true', help="Input fastq is not consensused.")
     if sub_program:
         parser.add_argument(
